@@ -94,22 +94,24 @@ def groupCleanup(db, groupname):
 
 
 def groupExists(groupname):
+	dbHost = hubzero.config.webconfig.getWebConfigDBHost()
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
 	dbName = hubzero.config.webconfig.getWebConfigDBName()
 
-	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection(dbHost, dbName, dbUserName, dbPW)
 	if _groupExists(db, groupname):
 		return True
 	else:
 		return False
 
 def groupNumberLookup(groupName):
+	dbHost = hubzero.config.webconfig.getWebConfigDBHost()
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
 	dbName = hubzero.config.webconfig.getWebConfigDBName()
 
-	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection(dbHost, dbName, dbUserName, dbPW)
 	return _groupExists(db, groupName)
 
 
@@ -135,10 +137,11 @@ def _del_jos_xgroups_members(db, gidNumber, uidNumber):
 
 
 def del_jos_xgroups_members(gidNumber, uidNumber):
+	dbHost = hubzero.config.webconfig.getWebConfigDBHost()
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
 	dbName = hubzero.config.webconfig.getWebConfigDBName()
-	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection(dbHost, dbName, dbUserName, dbPW)
 
 	_del_jos_xgroups_members(db, gidNumber, uidNumber)
 
@@ -222,10 +225,11 @@ def _insert_jos_xgroups_members(db, gidNumber, uidNumber):
 
 
 def insert_jos_xgroups_members(userName, groupName):
+	dbHost = hubzero.config.webconfig.getWebConfigDBHost()
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
 	dbName = hubzero.config.webconfig.getWebConfigDBName()
-	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection(dbHost, dbName, dbUserName, dbPW)
 
 	# look up uidNumber from username
 	uidNumber = hubzero.utilities.user.userLookup(userName)
@@ -239,11 +243,12 @@ def insert_jos_xgroups_members(userName, groupName):
 
 def delhubgroup(groupName):
 	# grab config options
+	dbHost = hubzero.config.webconfig.getWebConfigDBHost()
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
 	dbName = hubzero.config.webconfig.getWebConfigDBName()
 
-	db =  hubzero.data.db.MySQLConnection("localhost", dbUserName, dbName, dbPW)
+	db =  hubzero.data.db.MySQLConnection(dbHost, dbName, dbUserName, dbPW)
 	delete_ldap_group(groupName)
 	_del_jos_xgroups(db, groupName)
 	groupCleanup(db, groupName)
@@ -252,10 +257,11 @@ def delhubgroup(groupName):
 def addhubgroup(groupName, description='', gidNumber=0, type=0):
 
 	# grab config options
+	dbHost = hubzero.config.webconfig.getWebConfigDBHost()
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
 	dbName = hubzero.config.webconfig.getWebConfigDBName()
-	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection(dbHost, dbName, dbUserName, dbPW)
 
 	if not groupExists(groupName):
 		gidNumber = _insert_jos_xgroups(db, groupName, description, gidNumber, type)
@@ -269,10 +275,11 @@ def addhubgroup(groupName, description='', gidNumber=0, type=0):
 def addhubgroupdbonly(groupName, description='', gid=0, type=0):
 
 	# grab config options
+	dbHost = hubzero.config.webconfig.getWebConfigDBHost()
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
 	dbName = hubzero.config.webconfig.getWebConfigDBName()
-	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection(dbHost, dbName, dbUserName, dbPW)
 
 	gidNumber = _insert_jos_xgroups(db, groupName, description, type, gid)
 	return gidNumber	
@@ -395,10 +402,11 @@ def deleteuserfromgroup(userName, groupName):
 
 
 def getUserGroups(userName):
+	dbHost = hubzero.config.webconfig.getWebConfigDBHost()
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
 	dbName = hubzero.config.webconfig.getWebConfigDBName()
-	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection(dbHost, dbName, dbUserName, dbPW)
 
 	# get all user group memberships
 	sql = "SELECT `p`.`username`, `g`.`cn` FROM jos_xgroups_members m JOIN jos_xprofiles p on (p.uidNumber = m.uidNumber) JOIN jos_xgroups g on (g.gidNumber = m.gidNumber) WHERE `p`.`username` = %s "
@@ -433,10 +441,11 @@ def syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True, ve
 
 def _syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True, group = '*', verbose = False, debug = False):
 	
+	dbHost = hubzero.config.webconfig.getWebConfigDBHost()
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
 	dbName = hubzero.config.webconfig.getWebConfigDBName()
-	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection(dbHost, dbName, dbUserName, dbPW)
 	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
 	hubLDAPAcctMgrPW = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
 	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn")
@@ -519,10 +528,11 @@ def _delete_ldap_users(args):
 	# by only deleting users in db, any users that exist only in ldap will be preserved
 	if not args.deleteorphans:
 		print "Orphaned users in ldap without a corresponding group in the database will be PRESERVED"
+	        dbHost = hubzero.config.webconfig.getWebConfigDBHost()
 		dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 		dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
 		dbName = hubzero.config.webconfig.getWebConfigDBName()
-		db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+		db =  hubzero.data.db.MySQLConnection(dbHost, dbName, dbUserName, dbPW)
 	
 		# grab all users from db 
 		sql = "SELECT `username`, `name`, `userPassword`, `uidNumber`, `homeDirectory`, `loginShell`, `gid`, gidNumber from jos_xprofiles"
