@@ -65,11 +65,12 @@ def hashPassword(pw, hashtype = 'MD5'):
 
 
 def userExists(username, hubname = ""):
+	dbHost = hubzero.config.webconfig.getWebConfigDBHost(hubname)
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword(hubname)
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername(hubname)
 	dbName = hubzero.config.webconfig.getWebConfigDBName(hubname)
 
-	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection(dbHost, dbName, dbUserName, dbPW)
 	if _userExists(db, username):
 		return True
 	else:
@@ -85,11 +86,12 @@ def _userExists(db, username):
 
 
 def userLookup(username, hubname = ""):
+	dbHost = hubzero.config.webconfig.getWebConfigDBHost(hubname)
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword(hubname)
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername(hubname)
 	dbName = hubzero.config.webconfig.getWebConfigDBName(hubname)
 
-	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection(dbHost, dbName, dbUserName, dbPW)
 	rv = _userExists(db, username)
 	return rv
 
@@ -438,11 +440,12 @@ def addhubuser(hubname,
 	"""
 
 	# grab config options
+	dbHost = hubzero.config.webconfig.getWebConfigDBHost(hubname)
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword(hubname)
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername(hubname)
 	dbName = hubzero.config.webconfig.getWebConfigDBName(hubname)
 
-	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection(dbHost, dbName, dbUserName, dbPW)
 
 	# Parse gecos, it's a massive mess, but it's a holdover from the wild west days of unix and it's a comma delimited field 
 	# used in the /etc/passwd file to store personal info. It's comma delimited, and name is the first item in the list... 
@@ -555,10 +558,11 @@ def addhubuser(hubname,
 
 
 def delhubuser(username, hubname = ""):
+	dbHost = hubzero.config.webconfig.getWebConfigDBHost(hubname)
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword(hubname)
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername(hubname)
 	dbName = hubzero.config.webconfig.getWebConfigDBName(hubname)
-	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection(dbHost, dbName, dbUserName, dbPW)
 
 	sql = 'select id from `jos_users` where username = %s'
 	data = [username]
@@ -589,10 +593,11 @@ def updateUserPW(username, password, updateCMS = True, updateLDAP = True, hubnam
 	pass plaintext pw, we'll hash it
 	"""
 
+	dbHost = hubzero.config.webconfig.getWebConfigDBHost(hubname)
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword(hubname)
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername(hubname)
 	dbName = hubzero.config.webconfig.getWebConfigDBName(hubname)
-	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection(dbHost, dbName, dbUserName, dbPW)
 
 	userid = _getUserID(db, username)
 
@@ -686,10 +691,11 @@ def _syncuser(username, hubname = "", syncAttributes = False):
 	hubLDAPAcctMgrPW = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw", hubname)
 	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn", hubname)	
 
+	dbHost = hubzero.config.webconfig.getWebConfigDBHost(hubname)
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword(hubname)
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername(hubname)
 	dbName = hubzero.config.webconfig.getWebConfigDBName(hubname)
-	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection(dbHost, dbName, dbUserName, dbPW)
 
 	query = """SELECT u.id AS uidNumber, u.username AS uid, u.name AS cn, p.gidNumber, p.homeDirectory, p.loginShell, 
 	pwd.passhash AS userPassword, pwd.shadowLastChange, pwd.shadowMin, pwd.shadowMax, pwd.shadowWarning, 
@@ -801,11 +807,12 @@ def syncusers(hubname = "", purgeorphans = True, syncattributes = True, verbose
 
 
 def _syncusers(hubname = "", purgeorphans = True, syncattributes = True, user = '*', verbose = False, debug = False):
+	dbHost = hubzero.config.webconfig.getWebConfigDBHost(hubname)
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
 	dbName = hubzero.config.webconfig.getWebConfigDBName()
 	ldapServer = hubzero.config.webconfig.getComponentParam("com_system", "ldap_primary")
-	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection(dbHost, dbName, dbUserName, dbPW)
 
 	# normally this would be accomplished with a complete purge and a readd, but we can't have our larger sites with an empty user database for
 	# the length of time it would take this script to run, so we do it this way
@@ -874,11 +881,12 @@ def updateuser(username, hubname = "", fname="", mname="", lname="", email="", h
 	if not hubname:
 		hubname = hubzero.config.webconfig.getDefaultSite()
 
+	dbHost = hubzero.config.webconfig.getWebConfigDBHost(hubname)
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
 	dbName = hubzero.config.webconfig.getWebConfigDBName()
 	ldapServer = hubzero.config.webconfig.getComponentParam("com_system", "ldap_primary")
-	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+	db =  hubzero.data.db.MySQLConnection(dbHost, dbName, dbUserName, dbPW)
 	uidNumber = _getUserID(db, username)
 
 	_update_jos_xprofiles(db, hubname, uidNumber, fname, mname, lname, email, '', '', '', '', '', '', homedir) 
